pub fn read_git_file(
repo: &Path,
git_ref: &str,
file_path: &str,
) -> Option<String>Expand description
Read a file from a git ref via git show <ref>:<path>.
Returns None if the file doesn’t exist at the given ref,
the git command fails, or the output is not valid UTF-8.
All failures are logged at trace level for debugging with
--log-level trace --log-file debug.log.